@@ -78,15 +78,19 @@ get_libc_func(const char *f)
 	nextlib = dlopen("libc.so.6", RTLD_LAZY);
 
     fp = dlsym(nextlib, f);
-    assert(fp);
 
     return fp;
 }
 
 #define libc_func(name, rettype, ...)			\
     static rettype (*_ ## name) (__VA_ARGS__) = NULL;	\
-    if (_ ## name == NULL)				\
-        _ ## name = get_libc_func(#name);
+    if (_ ## name == NULL) {				\
+        _ ## name = get_libc_func(#name);		\
+        if (_ ## name == NULL) {			\
+            fprintf(stderr, "umockdev: could not get libc function "#name"\n"); \
+            abort();					\
+        }						\
+    }
 
 /* return rdev of a file descriptor */
 static dev_t
@@ -1211,8 +1215,11 @@ int prefix ## stat ## suffix (const char *path, struct stat ## suffix *st) \
 
 /* wrapper template for __xstat family; note that we abuse the sticky bit in
  * the emulated /dev to indicate a block device (the sticky bit has no
- * real functionality for device nodes) */
+ * real functionality for device nodes)
+ * This family got deprecated/dropped in glibc 2.32.9000, but we still need
+ * to keep it for a while for programs that were built against previous versions */
 #define WRAP_VERSTAT(prefix, suffix) \
+int prefix ## stat ## suffix (int ver, const char *path, struct stat ## suffix *st); \
 int prefix ## stat ## suffix (int ver, const char *path, struct stat ## suffix *st) \
 { \
     const char *p;								\
